"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Task_1 = require("fp-ts/lib/Task");
var _1 = require(".");
/**
 * Apply policy and delay by its amount if it results in a retry.
 * Returns updated status.
 */
exports.applyAndDelay = function (policy, status) {
    var newStatus = _1.applyPolicy(policy, status);
    return newStatus.previousDelay.foldL(function () { return Task_1.task.of(newStatus); }, function (millis) { return Task_1.delay(millis, newStatus); });
};
/**
 * Retry combinator for actions that don't raise exceptions, but
 * signal in their type the outcome has failed. Examples are the
 * `Option`, `Either` and `EitherT` monads.
 */
exports.retrying = function (policy, action, check) {
    var go = function (status) {
        return action(status).chain(function (a) {
            if (check(a)) {
                return exports.applyAndDelay(policy, status).chain(function (status) {
                    return status.previousDelay.foldL(function () { return Task_1.task.of(a); }, function () { return go(status); });
                });
            }
            else {
                return Task_1.task.of(a);
            }
        });
    };
    return go(_1.defaultRetryStatus);
};
//# sourceMappingURL=Task.js.map